@@ -143,7 +143,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
       Cancel  = 0x00000020, ///< Show Cancel-button. (this button reject()s the dialog; result set to QDialog::Rejected)
       Close   = 0x00000040, ///< Show Close-button. (this button closes the dialog)
       No      = 0x00000080, ///< Show No button. (this button closes the dialog and sets the result to KDialog::No)
-      Yes     = 0x00000100, ///< Show Yes button. (this button closes the fialog and sets the result to KDialog::Yes)
+      Yes     = 0x00000100, ///< Show Yes button. (this button closes the dialog and sets the result to KDialog::Yes)
       Reset   = 0x00000200, ///< Show Reset button
       Details = 0x00000400, ///< Show Details button. (this button will show the detail widget set with setDetailsWidget)
       User1   = 0x00001000, ///< Show User defined button 1.
